import React from 'react'
import { Form, FormGroup, FormControl, ControlLabel } from 'react-bootstrap'

export default class ExplorerOptions extends React.Component {
  constructor(props) {
    super(props);
    if (Object.keys(this.props.options).length === 0) {
      this.props.fetchOptions();
    }

    // Initial explore
    if (this.propsValid(props)) {
      props.explore(props.params.source, props.params.category);
    }

    this.handleSourceChange = this.handleSourceChange.bind(this);
    this.handleCategoryChange = this.handleCategoryChange.bind(this);
  }
  handleSourceChange(event) {
    let source = event.target.value;
    let category = this.props.options[event.target.value][0];
    this.props.explore(source, category);
    this.props.router.push(`/${this.props.type}/explore/${source}/${category}`);
  }
  handleCategoryChange(event) {
    let source = this.props.params.source;
    let category = event.target.value;
    this.props.explore(source, category);
    this.props.router.push(`/${this.props.type}/explore/${source}/${category}`);
  }
  propsValid(props) {
    if (!props.params
      || !props.params.source
      || !props.params.category
      || (props.params.source === "")
      || (props.params.category === "")) {
      return false
    }
    return true;
  }
  componentWillUpdate(nextProps, nextState) {
    // Check props
    if (!this.propsValid(nextProps)) {
      return
    }

    // No previous params
    if (!this.props.params.source && !this.props.params.category) {
      this.props.explore(this.props.params.source, this.props.params.category);
      return;
    }

    // Explore params changed
    if ((this.props.params.source !== nextProps.params.source)
      || (this.props.params.category !== nextProps.params.category)) {
      this.props.explore(nextProps.params.source, nextProps.params.category);
      return;
    }
  }
  prettyName(name) {
    return name.replace("_", " ")
      .split(" ")
      .map((w) => w[0].toUpperCase() + w.substr(1))
      .join(" ");
  }
  render() {
    // Should this componennt be displayed
    if (!this.props.display) {
      return null;
    }

    // Options are not yet fetched
    if (Object.keys(this.props.options).length === 0) {
      return null;
    }

    // Invalid props
    if (!this.propsValid(this.props)) {
      return
    }

    let source = this.props.params.source;
    let category = this.props.params.category;
    let categories = this.props.options[this.props.params.source];

    return (
      <div className="row">
        <div className="col-xs-12 col-md-12">
          <Form>
            <div className="row">
              <div className="col-xs-12 col-md-6">
                <FormGroup>
                  <ControlLabel>Source</ControlLabel>
                  <FormControl
                    bsClass="form-control input-sm"
                    componentClass="select"
                    onChange={this.handleSourceChange}
                    value={source}
                  >
                    {Object.keys(this.props.options).map(function(source) {
                      return (<option key={source} value={source}>{this.prettyName(source)}</option>)
                    }, this)}
                  </FormControl>
                </FormGroup>
              </div>
              <div className="col-xs-12 col-md-6">
                <FormGroup>
                  <ControlLabel>Category</ControlLabel>
                  <FormControl
                    bsClass="form-control input-sm"
                    componentClass="select"
                    onChange={this.handleCategoryChange}
                    value={category}
                  >
                    {categories.map(function(category) {
                      return (<option key={category} value={category}>{this.prettyName(category)}</option>)
                    }, this)}
                  </FormControl>
                </FormGroup>
              </div>
            </div>
          </Form>
        </div>
      </div>
    );
  }
}
