import React from 'react'
import { store } from '../store'
import { isUserLoggedIn } from '../actions/actionCreators'

import { Nav, Navbar, NavItem, NavDropdown, MenuItem } from 'react-bootstrap'
import { LinkContainer } from 'react-router-bootstrap'
import { Control, Form } from 'react-redux-form';

export default function NavBar(props) {
  return (
    <div>
      <Navbar fluid fixedTop collapseOnSelect>
        <Navbar.Header>
          <LinkContainer to="/">
            <Navbar.Brand><a href="#">Canapé</a></Navbar.Brand>
          </LinkContainer>
          <Navbar.Toggle />
        </Navbar.Header>
        <Navbar.Collapse>
          <MoviesDropdown username={props.userStore.username} />
          <ShowsDropdown username={props.userStore.username} />
          <WishlistDropdown username={props.userStore.username} />
          <UserDropdown
            username={props.userStore.username}
            logout={props.userLogout}
          />
          <Search
            model="movieStore"
            model="movieStore.search"
            placeholder="Search movies"
            router={props.router}
            search={props.movieStore.search}
            searchFunc={props.searchMovies}
            path='/movies/search'
            pathMatch='movies'
            params={props.params}
          />
          <Search
            model="showStore"
            model="showStore.search"
            placeholder="Search shows"
            router={props.router}
            search={props.showStore.search}
            searchFunc={props.searchShows}
            path='/shows/search'
            pathMatch='shows'
            params={props.params}
          />
        </Navbar.Collapse>
      </Navbar>
    </div>
  );
}

class Search extends React.Component {
  constructor(props) {
    super(props);
    this.handleSearch = this.handleSearch.bind(this);
    this.search(this.props);
  }
  handleSearch() {
    if (this.props.search === "") {
      return;
    }
    this.search(this.props);
    this.props.router.push(`${this.props.path}/${encodeURI(this.props.search)}`);
  }
  isActive() {
    const location = this.props.router.getCurrentLocation().pathname;
    return (location.indexOf(this.props.pathMatch) !== -1)
  }
  search(props) {
    if (!this.isActive()) {
      return;
    }

    // Search from the props if defined
    if (props.search !== "") {
      props.searchFunc({ key: props.search });
      return;
    }

    // Search from the url params
    if (props.params
      && props.params.search
      && props.params.search !== "") {
      props.searchFunc({ key: props.params.search });
      return;
    }
  }
  render() {
    if (!this.isActive()) {
      return null;
    }

    return(
      <Navbar.Form pullRight>
        <Form model={this.props.model} className="input-group" onSubmit={this.handleSearch}>
          <Control.text
            model={this.props.model}
            className="form-control"
            placeholder={this.props.placeholder}
            updateOn="change"
          />
        </Form>
      </Navbar.Form>
    );
  }
}

function MoviesDropdown(props) {
  if (props.username === "") {
    return null;
  }
  return(
    <Nav>
      <NavDropdown title="Movies" id="navbar-movies-dropdown">
        <LinkContainer to="/movies/explore/yts/seeds">
          <MenuItem>Explore</MenuItem>
        </LinkContainer>
        <LinkContainer to="/movies/polochon">
          <MenuItem>Polochon</MenuItem>
        </LinkContainer>
      </NavDropdown>
    </Nav>
  );
}

function ShowsDropdown(props) {
  if (props.username === "") {
    return null;
  }
  return(
    <Nav>
      <NavDropdown title="Shows" id="navbar-shows-dropdown">
        <LinkContainer to="/shows/explore/eztv/rating">
          <NavItem>Explore</NavItem>
        </LinkContainer>
        <LinkContainer to="/shows/polochon">
          <NavItem>Polochon</NavItem>
        </LinkContainer>
      </NavDropdown>
    </Nav>
  );
}

function UserDropdown(props) {
  if (props.username !== "") {
    return (
      <Nav pullRight>
        <NavDropdown title={props.username} id="navbar-dropdown-right">
          <LinkContainer to="/users/edit">
            <MenuItem>Edit</MenuItem>
          </LinkContainer>
          <LinkContainer to="/users/logout" onClick={props.logout}>
            <MenuItem>Logout</MenuItem>
          </LinkContainer>
        </NavDropdown>
      </Nav>
    );
  } else {
    return(
      <Nav pullRight>
        <LinkContainer to="/users/signup">
          <NavItem>Sign up</NavItem>
        </LinkContainer>
        <LinkContainer to="/users/login">
          <NavItem>Login</NavItem>
        </LinkContainer>
      </Nav>
    );
  }
}

function WishlistDropdown(props) {
  if (props.username === "") {
    return null;
  }
  return(
    <Nav>
      <NavDropdown title="Wishlist" id="navbar-wishlit-dropdown">
        <LinkContainer to="/movies/wishlist">
          <MenuItem>Movies</MenuItem>
        </LinkContainer>
        <LinkContainer to="/shows/wishlist">
          <MenuItem>Shows</MenuItem>
        </LinkContainer>
      </NavDropdown>
    </Nav>
  );
}
